@@ -127,7 +127,6 @@ class mPrefs:
              db.cursor.execute('UPDATE prefs SET value=? WHERE uuid=?;',[self.google_login,'google_login'])
              db.db.commit()
 
-
            if self.google_password==None:
              self.google_password = ''
              db.cursor.execute('INSERT INTO prefs (uuid , value) VALUES (?,?);',['google_password',''])
@@ -219,7 +218,7 @@ class Note:
               #self.title = self.description.split('\n')[0]
             self.google_updated = ((datetime.datetime.now().replace(tzinfo=dateutil.tz.tzlocal())).astimezone(dateutil.tz.tzutc())).strftime('%Y-%m-%dT%H:%M:%S.000Z')
             print 'Saved date:'+self.google_updated
-            
+
             db = Database(DB_PATH)
             if self.new==True:
               db.cursor.execute('INSERT INTO notes (uuid , title, description,type,google_id,google_last_update ) VALUES(?,?,?,?,?,?);',[self.uuid,self.title,self.description,self.type,self.google_id,self.google_last_update])
@@ -264,8 +263,12 @@ class Note:
 
         def delete_from_db(self):
             db = Database(DB_PATH)
-            db.cursor.execute('DELETE FROM notes WHERE uuid ="'+self.uuid + '";')
-            db.db.commit()
+            if self.google_id == '':
+              db.cursor.execute('DELETE FROM notes WHERE uuid ="'+self.uuid + '";')
+              db.db.commit()
+            else:
+              db.cursor.execute('UPDATE notes SET title="DELETED" WHERE uuid =?;',[self.uuid,])
+              db.db.commit()
             db.close()
 
 class NotesList:
@@ -279,7 +282,7 @@ class NotesList:
             db = Database(DB_PATH)
 
             select = 'SELECT uuid FROM notes  '
-            where = ''
+            where = ' WHERE title != "DELETED"'
             query = select + where
 
             db.cursor.execute(query)       
@@ -294,7 +297,7 @@ class NotesList:
             db = Database(DB_PATH)
 
             select = 'SELECT uuid FROM notes  '
-            where = ' WHERE description LIKE "%' +text+ '%"'
+            where = ' WHERE title != "DELETED" AND description LIKE "%' +text+ '%"'
             query = select + where
 
             db.cursor.execute(query)       
