@@ -40,12 +40,12 @@ class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.2.8"
+  __version__ = "0.3.0"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
-    #'/usr/lib/mnotes/ui/mnotes.glade',
-    'ui/mnotes.glade',
+    '/usr/lib/mnotes/ui/mnotes.glade',
+    #'ui/mnotes.glade',
   ]
 
   def __init__(self,app,context):
@@ -290,7 +290,7 @@ class mNotes(object):
     if (selection_iter):
       uuid = self._notesList.get_value(selection_iter, 0)
       self._save_current_note()
-      if self._current_selection_iter != None:
+      if (self._current_selection_iter != None) and (self._current_note != None):
         self._notesList.set_value(self._current_selection_iter, 1,self._current_note.title)
       self._current_selection_iter = selection_iter
       self._current_note = mnotes_framework.Note(uuid)
@@ -335,6 +335,7 @@ class mNotes(object):
         note = mnotes_framework.Note(uuid)
         self._notesList.remove(selection_iter)
         note.delete_from_db()
+        self._current_note = None
         selection = self.notesListTree.get_selection()
         self.notesListTree.set_cursor(0)
         selection.select_path(0)
@@ -743,7 +744,7 @@ class mNotes(object):
     if sync.get_last_error()!=None:
       self.warn(sync.get_last_error())
     self._load_noteslist_bg()
-  
+
   def warn(self,message):
     gtk.gdk.threads_enter()
     dialog = gtk.MessageDialog(gtk.Window(),
